#!/usr/bin/env python3
# -*- coding: utf-8 -*-


from airflow.models import DAG

from airflow.operators.bash_operator import BashOperator
from airflow.operators.python_operator import PythonOperator

import pendulum
import random
from datetime import timedelta, datetime

# time zone을 한국 시간으로 설정하려면 pendulum 등의 library를 이용한다.
local_tz = pendulum.timezone("Asia/Seoul")

"""
python_operator.py는 처음에 BashOperator를 사용하여 현재 시각을 설정하고 다음으로 Python 함수를 정의한 후에 PythonOperator에 의해 그 함수를 호출하고 난수를 표시하는 AG다.
"""

# DAG 객체로 이용할 공통된 인수를 정의한다.
default_args = {
    'owner': 'Airflow',
    'start_date': datetime(2019, 1, 1, tzinfo=pendulum.timezone('Asia/Seoul')),
    'depends_on_past': True,
    'retries': 1,
    'retry_delay': timedelta(minutes=5),
}

# DAG 객체를 정의한다.
# 여기서는 정기 실행의 정의(schedule_interval)를 '한 번만'으로 하고 있다.
dag = DAG(
    dag_id='python_operator',
    default_args=default_args,
    schedule_interval='@once',
)


# 우선은 BashOperator를 사용하여 현재 시각을 표시한다.
operator_1 = BashOperator(
    task_id='operator_1',
    bash_command='echo {}'.format(datetime.now()),
    dag=dag,
)


# 다음으로 PythonOperator를 작성한다.
# PythonOpeartor에서는 호출할 함수를 먼저 정의할 필요가 있다.
# 그 함수에서 인수를 설정하는 것도 가능하다.
def print_random(rnd):
    print(rnd)
    return '이 반환값은 log에 출력됩니다;' + str(rnd)


# 난수를 발생시킨다.
rnd = random.random()
# 다음으로 PythonOperator를 사용하여 난수를 표시한다.
operator_2 = PythonOperator(
    task_id='python_operator',
    python_callable=print_random,
    op_kwargs={'rnd': rnd},
    dag=dag,
)


# Operation의 의존관계를 정의한다.
operator_1 >> operator_2